@@ -1,6 +1,6 @@
 /* -*- mode: C; c-basic-offset: 4 -*-
  * pyorbit - a Python language mapping for the ORBit2 CORBA ORB
- * Copyright (C) 2002  James Henstridge <james@daa.com.au>
+ * Copyright (C) 2002-2003  James Henstridge <james@daa.com.au>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -22,16 +22,45 @@
 #endif
 #include "pyorbit-private.h"
 #include <orbit/poa/poa-types.h>
+#ifdef HAVE_ORBIT2_IMODULE
+#  include <ORBitservices/orbit-imodule.h>
+#endif
 
 PortableServer_POA _pyorbit_poa;
 
+static void
+pyorbit_handle_types_and_interfaces(CORBA_sequence_ORBit_IInterface *ifaces,
+				    CORBA_sequence_CORBA_TypeCode *types,
+				    const gchar *file)
+{
+    gint i;
+
+    for (i = 0; i < ifaces->_length; i++) {
+	if (ifaces->_buffer[i].tc->kind == CORBA_tk_null)
+	    g_warning("%s is possibly broken: tc->kind == tk_null",
+		      file);
+
+	pyorbit_generate_iinterface_stubs(&ifaces->_buffer[i]);
+	_pyorbit_register_skel(&ifaces->_buffer[i]);
+    }
+
+    for (i = 0; i < types->_length; i++) {
+	CORBA_TypeCode tc = types->_buffer[i];
+
+	if (tc->kind == CORBA_tk_null ||
+	    (tc->kind==CORBA_tk_alias && tc->subtypes[0]->kind==CORBA_tk_null))
+	    g_warning("%s is possibly broken: tc->kind == tk_null",
+		      file);
+	pyorbit_generate_typecode_stubs(tc);
+    }
+}
+
 static PyObject *
 pyorbit_load_typelib(PyObject *self, PyObject *args)
 {
     gchar *typelib;
     CORBA_sequence_ORBit_IInterface *ifaces;
     CORBA_sequence_CORBA_TypeCode *types;
-    gint i;
 
     if (!PyArg_ParseTuple(args, "s", &typelib))
 	return NULL;
@@ -40,33 +69,51 @@ pyorbit_load_typelib(PyObject *self, PyObject *args)
 	return NULL;
     }
     ifaces = ORBit_small_get_iinterfaces(typelib);
-    for (i = 0; i < ifaces->_length; i++) {
-	if (ifaces->_buffer[i].tc->kind == CORBA_tk_null)
-	    g_warning("typelib %s is possibly broken: tc->kind == tk_null",
-		      typelib);
-
-	pyorbit_generate_iinterface_stubs(&ifaces->_buffer[i]);
-	_pyorbit_register_skel(&ifaces->_buffer[i]);
-    }
-    CORBA_free(ifaces);
     types = ORBit_small_get_types(typelib);
-    for (i = 0; i < types->_length; i++) {
-	CORBA_TypeCode tc = types->_buffer[i];
 
-	if (tc->kind == CORBA_tk_null ||
-	    (tc->kind==CORBA_tk_alias && tc->subtypes[0]->kind==CORBA_tk_null))
-	    g_warning("typelib %s is possibly broken: tc->kind == tk_null",
-		      typelib);
-	pyorbit_generate_typecode_stubs(tc);
-    }
+    pyorbit_handle_types_and_interfaces(ifaces, types, typelib);
+
+    CORBA_free(ifaces);
     CORBA_free(types);
 
     Py_INCREF(Py_None);
     return Py_None;
 }
 
+static PyObject *
+pyorbit_load_file(PyObject *self, PyObject *args)
+{
+#ifdef HAVE_ORBIT2_IMODULE
+    gchar *path, *cpp_args = "";
+    CORBA_sequence_ORBit_IInterface *ifaces;
+    CORBA_sequence_CORBA_TypeCode *types;
+
+    if (!PyArg_ParseTuple(args, "s|s", &path, &cpp_args))
+	return NULL;
+    ifaces = ORBit_iinterfaces_from_file(path, cpp_args, &types);
+    if (!ifaces) {
+	PyErr_Format(PyExc_RuntimeError, "could not load '%s'", path);
+	return NULL;
+    }
+
+    pyorbit_handle_types_and_interfaces(ifaces, types, path);
+
+    //CORBA_free(ifaces);
+    //CORBA_free(types);
+
+    Py_INCREF(Py_None);
+    return Py_None;
+#else
+    PyErr_SetString(PyExc_RuntimeError,
+		    "pyorbit was not configured with support for the "
+		    "imodule service");
+    return NULL;
+#endif
+}
+
 static PyMethodDef orbit_functions[] = {
     { "load_typelib", pyorbit_load_typelib, METH_VARARGS },
+    { "load_file",    pyorbit_load_file,    METH_VARARGS },
     { NULL, NULL, 0 }
 };
 
