@@ -1,6 +1,6 @@
 /* -*- mode: C; c-basic-offset: 4 -*-
  * pyorbit - a Python language mapping for the ORBit2 CORBA ORB
- * Copyright (C) 2002  James Henstridge <james@daa.com.au>
+ * Copyright (C) 2002-2003  James Henstridge <james@daa.com.au>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -610,9 +610,15 @@ demarshal_value(CORBA_TypeCode tc, gconstpointer *val)
 	}
 	break;
     case CORBA_tk_longlong:
-	return PyLong_FromLongLong(getval(val, CORBA_long_long));
+	alignval(val, ORBIT_ALIGNOF_CORBA_LONG_LONG);
+	ret = PyLong_FromLongLong(getval(val, CORBA_long_long));
+	advanceptr(val, sizeof(CORBA_long_long));
+	break;
     case CORBA_tk_ulonglong:
-	return PyLong_FromUnsignedLongLong(getval(val, CORBA_unsigned_long_long));
+	alignval(val, ORBIT_ALIGNOF_CORBA_LONG_LONG);
+	ret = PyLong_FromUnsignedLongLong(getval(val, CORBA_unsigned_long_long));
+	advanceptr(val, sizeof(CORBA_unsigned_long_long));
+	break;
     case CORBA_tk_longdouble:
 	g_warning("can't demarshal long doubles");
 	break;
