@@ -1,6 +1,6 @@
 /* -*- mode: C; c-basic-offset: 4 -*-
  * pyorbit - a Python language mapping for the ORBit2 CORBA ORB
- * Copyright (C) 2002  James Henstridge <james@daa.com.au>
+ * Copyright (C) 2002-2003  James Henstridge <james@daa.com.au>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -300,7 +300,8 @@ pycorba_method_get_doc(PyCORBA_Method *self, void *closure)
     for (i = 0; i < self->imethod->arguments._length; i++) {
 	if ((self->imethod->arguments._buffer[i].flags &
 	     (ORBit_I_ARG_IN | ORBit_I_ARG_INOUT)) != 0) {
-	    g_string_append(string, self->imethod->arguments._buffer[i].name);
+	    const gchar *argname = self->imethod->arguments._buffer[i].name;
+	    g_string_append(string, argname ? argname : "arg");
 	    g_string_append(string, ", ");
 	    has_arg = TRUE;
 	}
