@@ -1,6 +1,6 @@
 /* -*- mode: C; c-basic-offset: 4 -*-
  * pyorbit - a Python language mapping for the ORBit2 CORBA ORB
- * Copyright (C) 2002  James Henstridge <james@daa.com.au>
+ * Copyright (C) 2002-2003  James Henstridge <james@daa.com.au>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,6 +25,8 @@
 #include "pyorbit-private.h"
 #include <structmember.h>
 #include <orbit/poa/poa-types.h>
+#include <orbit/orbit-config.h>
+
 
 struct _PyORBitInterfaceInfo {
     ORBit_IInterface *iinterface;
@@ -76,7 +78,11 @@ _pyorbit_register_skel(ORBit_IInterface *iinterface)
 
     info = g_new0(PyORBitInterfaceInfo, 1);
     info->iinterface = iinterface;
+#if  (ORBIT_MAJOR_VERSION > 2 || (ORBIT_MAJOR_VERSION == 2 && ORBIT_MINOR_VERSION >= 7))
+    info->class_info.impl_finder = &impl_finder_func;
+#else
     info->class_info.small_relay_call = &impl_finder_func;
+#endif
     info->class_info.class_name = g_strdup(iinterface->tc->repo_id);
     info->class_info.class_id = &info->classid;
     info->class_info.idata = iinterface;
